==> studio-create-4.9.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.

<a name="4.9.0"></a>
# 4.9.0 (2017-10-09)


### Bug Fixes

* remove business options from generate command ([ab88684](https://github.com/SUI-Components/sui/commit/ab88684))
* remove wrong tabs in package.json ([c029da5](https://github.com/SUI-Components/sui/commit/c029da5))


### Features

* update with new deploy method ([8a7aab4](https://github.com/SUI-Components/sui/commit/8a7aab4))



<a name="4.8.0"></a>
# 4.8.0 (2017-10-04)


### Bug Fixes

* add missing dependency ([22813f4](https://github.com/SUI-Components/sui/commit/22813f4))



<a name="4.6.0"></a>
# 4.6.0 (2017-09-21)


### Features

* Move package from [@schibstedspain](https://github.com/schibstedspain) scope to [@s-ui](https://github.com/s-ui) org ([2469e1a](https://github.com/SUI-Components/sui/commit/2469e1a))



<a name="4.5.0"></a>
# 4.5.0 (2017-08-17)


### Features

* perform npm install after creating studio ([11024bd](https://github.com/SUI-Components/sui/commit/11024bd))



<a name="4.4.0"></a>
# 4.4.0 (2017-07-20)


### Bug Fixes

* wrong package.json generation ([5bebaff](https://github.com/SUI-Components/sui/commit/5bebaff))



<a name="4.3.0"></a>
# 4.3.0 (2017-07-13)


### Bug Fixes

* improve phoenix scripts for generated pacakge.json ([dfd35e6](https://github.com/SUI-Components/sui/commit/dfd35e6))
* wrong package.json generation ([16b7269](https://github.com/SUI-Components/sui/commit/16b7269))



<a name="4.1.0"></a>
# 4.1.0 (2017-06-25)


### Features

* add updated sui-studio-create behavior ([ec6677f](https://github.com/SUI-Components/sui/commit/ec6677f))

==> studio-create-4.10.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.

<a name="4.10.0"></a>
# 4.10.0 (2018-09-17)


### Features

* update commands + add release & dev scripts in template ([f472f3a](https://github.com/SUI-Components/sui/commit/f472f3a))



<a name="4.9.0"></a>
# 4.9.0 (2017-10-09)


### Bug Fixes

* remove business options from generate command ([ab88684](https://github.com/SUI-Components/sui/commit/ab88684))
* remove wrong tabs in package.json ([c029da5](https://github.com/SUI-Components/sui/commit/c029da5))


### Features

* update with new deploy method ([8a7aab4](https://github.com/SUI-Components/sui/commit/8a7aab4))



<a name="4.8.0"></a>
# 4.8.0 (2017-10-04)


### Bug Fixes

* add missing dependency ([22813f4](https://github.com/SUI-Components/sui/commit/22813f4)), closes [#126](https://github.com/SUI-Components/sui/issues/126)



<a name="4.6.0"></a>
# 4.6.0 (2017-09-21)


### Features

* Move package from [@schibstedspain](https://github.com/schibstedspain) scope to [@s-ui](https://github.com/s-ui) org ([2469e1a](https://github.com/SUI-Components/sui/commit/2469e1a))



<a name="4.5.0"></a>
# 4.5.0 (2017-08-17)


### Features

* perform npm install after creating studio ([11024bd](https://github.com/SUI-Components/sui/commit/11024bd)), closes [#88](https://github.com/SUI-Components/sui/issues/88)



<a name="4.4.0"></a>
# 4.4.0 (2017-07-20)


### Bug Fixes

* wrong package.json generation ([5bebaff](https://github.com/SUI-Components/sui/commit/5bebaff))



<a name="4.3.0"></a>
# 4.3.0 (2017-07-13)


### Bug Fixes

* improve phoenix scripts for generated pacakge.json ([dfd35e6](https://github.com/SUI-Components/sui/commit/dfd35e6)), closes [/github.com/SUI-Components/sui/pull/18#discussion_r124194618](https://github.com//github.com/SUI-Components/sui/pull/18/issues/discussion_r124194618)
* wrong package.json generation ([16b7269](https://github.com/SUI-Components/sui/commit/16b7269))



<a name="4.1.0"></a>
# 4.1.0 (2017-06-25)


### Features

* add updated sui-studio-create behavior ([ec6677f](https://github.com/SUI-Components/sui/commit/ec6677f))
